==> munit-remote-2.3.5-sources.jar: org/mule/munit/remote/container/model/SuiteDeployment.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.remote.container.model;

import static com.google.common.base.Preconditions.checkArgument;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

/**
 * Represents a suite to be run
 *
 * @author Mulesoft Inc.
 * @since 2.2.0
 */
public class SuiteDeployment {

  private Set<SuiteRun> suiteRuns;
  private Map<String, String> systemProperties;
  private boolean enableXmlValidations;

  private SuiteDeployment(Set<SuiteRun> suiteRuns, Map<String, String> systemProperties, boolean enableXmlValidations) {
    this.suiteRuns = suiteRuns;
    this.systemProperties = systemProperties;
    this.enableXmlValidations = enableXmlValidations;
  }

  public Set<SuiteRun> getSuiteRuns() {
    return suiteRuns;
  }

  public boolean isEnableXmlValidations() {
    return enableXmlValidations;
  }

  public Map<String, String> getSystemProperties() {
    return systemProperties;
  }

  public static Builder builder() {
    return new Builder();
  }

  /**
   * Builds a {@link SuiteDeployment}
   * 
   * @author Mulesoft Inc.
   * @since 2.2.0
   */
  public static class Builder {

    private Set<SuiteRun> suiteRuns;
    private Map<String, String> systemProperties = new HashMap<>();
    private boolean enableXmlValidations = true;

    private Builder() {}

    public Builder withSuiteRuns(Set<SuiteRun> suiteRuns) {
      checkArgument(suiteRuns != null, "Suite runs cannot be null");
      checkArgument(!suiteRuns.isEmpty(), "Suite runs cannot be empty");
      this.suiteRuns = suiteRuns;
      return this;
    }

    public Builder withSystemProperties(Map<String, String> systemProperties) {
      checkArgument(systemProperties != null, "Parameterization name cannot be null");
      this.systemProperties = systemProperties;
      return this;
    }

    public Builder withEnableXmlValidations(boolean enableXmlValidations) {
      this.enableXmlValidations = enableXmlValidations;
      return this;
    }

    public SuiteDeployment build() {
      return new SuiteDeployment(suiteRuns, systemProperties, enableXmlValidations);
    }
  }

}

==> munit-remote-3.1.0-sources.jar: org/mule/munit/remote/container/model/SuiteDeployment.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.remote.container.model;

import static org.mule.munit.common.util.Preconditions.checkArgument;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

/**
 * Represents a suite to be run
 *
 * @author Mulesoft Inc.
 * @since 2.2.0
 */
public class SuiteDeployment {

  private Set<SuiteRun> suiteRuns;
  private Map<String, String> systemProperties;
  private boolean enableXmlValidations;

  private SuiteDeployment(Set<SuiteRun> suiteRuns, Map<String, String> systemProperties, boolean enableXmlValidations) {
    this.suiteRuns = suiteRuns;
    this.systemProperties = systemProperties;
    this.enableXmlValidations = enableXmlValidations;
  }

  public Set<SuiteRun> getSuiteRuns() {
    return suiteRuns;
  }

  public boolean isEnableXmlValidations() {
    return enableXmlValidations;
  }

  public Map<String, String> getSystemProperties() {
    return systemProperties;
  }

  public static Builder builder() {
    return new Builder();
  }

  /**
   * Builds a {@link SuiteDeployment}
   * 
   * @author Mulesoft Inc.
   * @since 2.2.0
   */
  public static class Builder {

    private Set<SuiteRun> suiteRuns;
    private Map<String, String> systemProperties = new HashMap<>();
    private boolean enableXmlValidations = true;

    private Builder() {}

    public Builder withSuiteRuns(Set<SuiteRun> suiteRuns) {
      checkArgument(suiteRuns != null, "Suite runs cannot be null");
      checkArgument(!suiteRuns.isEmpty(), "Suite runs cannot be empty");
      this.suiteRuns = suiteRuns;
      return this;
    }

    public Builder withSystemProperties(Map<String, String> systemProperties) {
      checkArgument(systemProperties != null, "Parameterization name cannot be null");
      this.systemProperties = systemProperties;
      return this;
    }

    public Builder withEnableXmlValidations(boolean enableXmlValidations) {
      this.enableXmlValidations = enableXmlValidations;
      return this;
    }

    public SuiteDeployment build() {
      return new SuiteDeployment(suiteRuns, systemProperties, enableXmlValidations);
    }
  }

}
